@@ -23,7 +23,7 @@
  *         Software Research Associates, Inc., Tokyo, Japan
  *         erik@sra.co.jp
  */
-static char rcsid[] = "$Id: SelFile.c,v 1.1 1994/08/30 15:42:31 pierre Exp $";
+static char rcsid[] = "$Id: SelFile.c,v 1.3 1996/10/28 13:35:05 pierre Exp $";
 
 /*
  * Author's address:
@@ -47,7 +47,9 @@ static char rcsid[] = "$Id: SelFile.c,v 1.1 1994/08/30 15:42:31 pierre Exp $";
 /* BSD 4.3 errno.h does not declare errno */
 extern int errno;
 extern int sys_nerr;
+#ifndef __FreeBSD__
 extern char *sys_errlist[];
+#endif
 
 #include <sys/param.h>
 #include <X11/cursorfont.h>
