@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: bouton.c,v 1.6 1996/10/28 13:35:41 pierre Exp $";
+static char rcsid[] = "$Id: bouton.c,v 1.7 1997/07/03 08:20:04 pierre Exp $";
 
 /*
  * fonctions associees aux boutons
@@ -97,16 +97,16 @@ char *s;
 }
 
 
-void Charge ()
+int Charge ()
 {
     static struct stat statb;
 
     if (strlen(nom_fichier_charge) == 0)
-      return;
+      return -1;
 
     if (stat (nom_fichier_charge, &statb) < 0) {
 	affiche_erreur (xtel_basename(nom_fichier_charge), errno);
-	return;
+	return -1;
     }
 
     /* Prepare l'ecran */
@@ -116,6 +116,8 @@ void Charge ()
     /* Lecteur */
     raz_lecteur ();
     lecteur_valide (True);
+
+    return 0;
 }
 
 void Sauve()
