@@ -17,12 +17,13 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: config.c,v 1.10 1996/09/29 12:45:33 pierre Exp $";
+static char rcsid[] = "$Id: config.c,v 1.12 1997/02/21 16:58:25 pierre Exp $";
 
 /*
  * fonctions de lecture de la configuration
  */
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #ifdef USE_SYSLOG
 #include <syslog.h>
@@ -123,10 +124,6 @@ lecture_services ()
 
 	strcpy (buf1, next_token (buf, ","));
 
-#ifdef DEBUG_XTELD
-    log_debug ("buf1 = %s", buf1);
-#endif
-
 	if (!flag_old_config) {
 	    definition_services[i].device = strdup (buf1);
 	    strcpy (buf1, next_token (NULL, ","));
@@ -135,32 +132,19 @@ lecture_services ()
 	    definition_services[i].device = NULL;
 
 	definition_services[i].nom_service = strdup (buf1);
-#ifdef DEBUG_XTELD
-    log_debug ("nom_service = %s", definition_services[i].nom_service);
-#endif
-
 	strcpy (buf1, next_token (NULL, ","));
-
-#ifdef DEBUG_XTELD
-    log_debug ("buf1 = %s", buf1);
-#endif
-
        	definition_services[i].nom_uucp = strdup (buf1);
 
 	/* lecture des autorisations */
 	strcpy (buf1, next_token (NULL, ","));
 
-#ifdef DEBUG_XTELD
-    log_debug ("buf1 = %s", buf1);
-#endif
-
 	definition_services[i].autorisations = strdup (buf1);
 
 #ifdef DEBUG_XTELD
 	if (!flag_old_config)
-	    log_debug ("%s %s %s %s", definition_services[i].device, definition_services[i].nom_service, definition_services[i].nom_uucp, definition_services[i].autorisations);
+	    log_debug ("SERVICES: %s %s %s %s", definition_services[i].device, definition_services[i].nom_service, definition_services[i].nom_uucp, definition_services[i].autorisations);
 	else
-	    log_debug ("%s %s %s", definition_services[i].nom_service, definition_services[i].nom_uucp, definition_services[i].autorisations);
+	    log_debug ("SERVICES: %s %s %s", definition_services[i].nom_service, definition_services[i].nom_uucp, definition_services[i].autorisations);
 #endif
 	i++;
     }
@@ -270,9 +254,9 @@ lecture_configuration_lignes ()
 
 #ifdef DEBUG_XTELD
 	if (!flag_old_config)
-	    log_debug ("LA LIGNE****> %s %s %d %d %d >%s< %d", definition_lignes[i].device, definition_lignes[i].nom, definition_lignes[i].speed, definition_lignes[i].cs, definition_lignes[i].parity, definition_lignes[i].chat, definition_lignes[i].delai);
+	    log_debug ("LIGNES: %s %s %d %d %d >%s< %d", definition_lignes[i].device, definition_lignes[i].nom, definition_lignes[i].speed, definition_lignes[i].cs, definition_lignes[i].parity, definition_lignes[i].chat, definition_lignes[i].delai);
 	else
-	    log_debug ("%s %s %d", definition_lignes[i].nom, definition_lignes[i].chat, definition_lignes[i].delai);
+	    log_debug ("LIGNES: %s %s %d", definition_lignes[i].nom, definition_lignes[i].chat, definition_lignes[i].delai);
 #endif
 	i++;
     }
