@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: demon.h,v 1.6 1996/10/14 12:20:16 pierre Exp $"
+#ident "$Id: demon.h,v 1.8 1997/01/08 15:00:28 pierre Exp $"
 
 #ifndef _demon_h
 #define _demon_h
@@ -53,6 +53,11 @@
 #define CS8	3
 #endif /* NO_TERMIO */
 
+/* IAN */
+#define IAN_DE_GARDE 3
+#define IAN_D_ENTREE 2
+#define IAN_DE_FIN 1
+
 /* 
  * Structure de definition des services
  */
@@ -87,6 +92,7 @@ struct definition_ligne {
 #define VALEUR_COMMANDE_SERVICE_SUIVANT		130
 #define VALEUR_COMMANDE_NOM_UUCP		131
 #define VALEUR_COMMANDE_CONNEXION_M1		132
+#define VALEUR_TEMPS_MAXI			133
 
 #define CHAINE_COMMANDE_DEMANDE_CONNEXION	"\200"
 #define CHAINE_COMMANDE_FIN			"\201"
@@ -105,6 +111,7 @@ struct definition_ligne {
 #define CHAINE_REPONSE_PLUS_DE_SERVICE		"\202"
 #define CHAINE_REPONSE_DEBUT_ERREUR		"\203"
 #define CHAINE_REPONSE_FIN_ERREUR		"\204"
+#define CHAINE_TEMPS_MAXI			"\205"
 
 #ifdef NO_NETWORK
 #define XTEL_UNIX_PATH		"/tmp/.xtel"	/* Nom des sockets unix utilisees */
