@@ -18,7 +18,7 @@
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *		 
  */
-static char rcsid[] = "$Id: dial.c,v 1.13 1996/10/28 13:36:37 pierre Exp $";
+static char rcsid[] = "$Id: dial.c,v 1.15 1997/07/04 14:47:01 pierre Exp $";
 
 /*
  * Composition des numeros telephoniques
@@ -61,7 +61,7 @@ static char rcsid[] = "$Id: dial.c,v 1.13 1996/10/28 13:36:37 pierre Exp $";
 #ifdef USE_SYSLOG
 #include <syslog.h>
 #endif /* USE_SYSLOG */
-#if defined(lectra) && defined(SVR4) && !defined(sun)
+#if (defined(lectra) && defined(SVR4) && !defined(sun)) || defined(hpux)
 #include <sys/termiox.h>
 #endif
 
@@ -77,9 +77,9 @@ static struct termios term_sauve, term;
 static struct termio term_sauve, term;
 #endif /* USE_TERMIOS */
 #endif /* NO_TERMIO */
-#if defined(lectra) && defined(SVR4) && !defined(sun)
+#if (defined(lectra) && defined(SVR4) && !defined(sun)) || defined(hpux)
 static struct termiox termx;
-#endif /* lectra && SVR4 && !sun */
+#endif /* lectra && SVR4 && !sun || hpux */
 
 static char nom_lck[256];
 static fd_set a_lire;
@@ -150,6 +150,7 @@ do_chat (fd, chat_script, telno)
 int fd;
 char *chat_script, *telno;
 {
+    fd_set t_a_lire;
     int i, erreur, fin, nbread, cmodem;
     char *pt_chat, c;
 
@@ -319,11 +320,12 @@ char *chat_script, *telno;
 	i = 0;
 
 	for (;;) {
-
-	    nbread = select (32, &a_lire, NULL, NULL, &delai_maxi);
+	    
+	    t_a_lire = a_lire;
+	    nbread = select (32, &t_a_lire, NULL, NULL, &delai_maxi);
 
 	    /* Si il y a qque chose a lire */
-	    if (nbread > 0 && FD_ISSET (fd, &a_lire)) {
+	    if (nbread > 0 && FD_ISSET (fd, &t_a_lire)) {
 		if (read (fd, &c, 1) == 1)  {
 		    char voulu;
 #ifdef DEBUG_XTELD
@@ -484,7 +486,7 @@ char *telno, *device;
 	    if (stat (nom_lck, &statb) == 0) {
 		if (numero_ligne == nb_lignes-1) {
 		    /* Dommage, c'etait la derniere :-( */
-		    erreur_a_xtel ("[0] Pas de MODEM disponible !", 0);
+		    erreur_a_xtel ("[0] Aucun MODEM disponible !", 0);
 		    return (-1);
 		}
 	    }
@@ -513,7 +515,7 @@ char *telno, *device;
 	log_debug ("Ouverture de la ligne %s", definition_lignes[numero_ligne].nom);
 #endif
 	/* ouvre la ligne */
-	if ((fd = open (definition_lignes[numero_ligne].nom, O_RDWR)) < 0) {
+	if ((fd = open (definition_lignes[numero_ligne].nom, O_RDWR|O_NDELAY)) < 0) {
 	    /* Derniere ligne, on passe l'erreur */
 	    if (numero_ligne == nb_lignes-1) {
 		erreur_a_xtel (definition_lignes[numero_ligne].nom, errno);
@@ -628,8 +630,8 @@ char *telno, *device;
 
 #endif /* NO_TERMIO */
 
-	/* RTS/CTS sur LS/UX */
-#if defined(lectra) && defined(SVR4) && !defined(sun)
+	/* RTS/CTS sur LS/UX ou HP/UX */
+#if (defined(lectra) && defined(SVR4) && !defined(sun)) || defined(hpux)
 	if (definition_lignes[numero_ligne].flags & FLAG_RTS_CTS) {
 #ifdef DEBUG_XTELD
 	    log_debug ("passe la ligne %d en RTS/CTS", numero_ligne);
@@ -638,7 +640,7 @@ char *telno, *device;
 	    termx.x_hflag |= (RTSXOFF|CTSXON);
 	    ioctl(fd, TCSETXW, &termx);
 	}
-#endif /* lectra && SVR4 && !sun */
+#endif /* lectra && SVR4 && !sun || hpux */
 	
 #ifdef DEBUG_XTELD
 	log_debug ("Dialogue Modem...");
@@ -672,7 +674,7 @@ char *telno, *device;
      * Erreur connexion !
      */
 
-    erreur_a_xtel ("[0] Pas de MODEM disponible !", 0);
+    erreur_a_xtel ("[0] Aucun MODEM disponible !", 0);
 
     close (fd);
 
