@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: global.h,v 1.8 1996/10/07 10:39:19 pierre Exp $"
+#ident "$Id: global.h,v 1.9 1997/07/03 08:22:34 pierre Exp $"
 
 #ifndef _global_h
 #define _global_h
@@ -51,7 +51,7 @@ void enregistre_caractere (Widget w, XtPointer client_data, char *s);
 void evenement_entre_widget(Widget w, char *client_data, XEvent *pevent);
 void commandes(Widget w, char *code, XtPointer call_data);
 char *xtel_basename(char *s);
-void Charge(void);
+int Charge(void);
 void Sauve(void);
 void composition_valide(int flag);
 void clavier_minitel_valide(int flag);
@@ -135,7 +135,7 @@ void enregistre_caractere ();
 void evenement_entre_widget();
 void commandes();
 char *xtel_basename();
-void Charge();
+int Charge();
 void Sauve();
 void composition_valide();
 void clavier_minitel_valide();
@@ -233,6 +233,7 @@ EXTERN char numero_courant[256];
 EXTERN ressources_xtel rsc_xtel;
 EXTERN int nb_protocoles;
 EXTERN struct protocole protocoles[MAXPROTO];
+EXTERN unsigned long black_pixel, white_pixel;
 
 /* bouton.c */
 EXTERN long position_courante_fichier;
