@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: globald.h,v 1.5 1996/09/22 21:10:26 pierre Exp $"
+#ident "$Id: globald.h,v 1.7 1996/12/20 16:16:38 pierre Exp $"
 
 #ifndef _globald_h
 #define _globald_h
@@ -53,10 +53,8 @@ EXTERN FILE *fp_console;
 #ifdef __STDC__
 
 /* xteld.c */
-void demande_fin_fils(void);
 void erreur_a_xtel(char *s, int code_erreur);
-int service_autorise(int indice_service);
-void deconnexion(void);
+int service_autorise(int indice_service, int *);
 void appel_service(char *service_teletel);
 int main(int ac, char **av);
 /* dial.c */
@@ -68,13 +66,14 @@ int lecture_configuration_lignes(void);
 /* misc.c */
 char *next_token(char *, char *);
 char *build_name(char *);
+/* ian.c */
+int ian_valide (int, char);
+void ian_init (char*);
 
 #else
 
-void demande_fin_fils();
 void erreur_a_xtel();
 int service_autorise();
-void deconnexion();
 void appel_service();
 int main();
 void myundial();
@@ -83,6 +82,8 @@ int lecture_services();
 int lecture_configuration_lignes();
 char *next_token();
 char *build_name();
+int ian_valide ();
+void ian_init ();
 
 #endif /* __STDC__ */
 
