@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: ligne.c,v 1.6 1996/10/28 13:36:58 pierre Exp $";
+static char rcsid[] = "$Id: ligne.c,v 1.8 1997/02/11 13:22:54 pierre Exp $";
 
 /*
  * fonctions de traitement de la ligne MODEM
@@ -37,6 +37,38 @@ static char rcsid[] = "$Id: ligne.c,v 1.6 1996/10/28 13:36:58 pierre Exp $";
 #endif /* NO_NETWORK */
 
 static char erreur, compte_erreur, message_erreur[80];
+static char buf_temps_maxi[4];
+static int temps_maxi;
+static XtIntervalId bip_id;
+
+/* Signale la deconnexion dans 30 s */
+static XtTimerCallbackProc bip_bip (w, id)
+Widget w;
+XtIntervalId *id;
+{
+  XKeyboardControl kb;
+  XKeyboardState kbs;
+  Display *display = XtDisplay(ecran_minitel);
+  int pitch[3]    = {200, 400, 500};
+  int duration[3] = { 50, 100, 100}, i;
+
+  XGetKeyboardControl (display, &kbs);
+
+  for (i = 0; i < 3; i++) {
+	kb.bell_pitch = pitch[i];
+	kb.bell_duration = duration[i];
+	XChangeKeyboardControl(display, KBBellPitch | KBBellDuration, &kb);
+  
+	XBell(display, 100);
+	XFlush(display);
+	usleep(100000L);
+  }
+
+  kb.bell_pitch = kbs.bell_pitch;
+  kb.bell_duration = kbs.bell_duration;
+
+  XChangeKeyboardControl (display, KBBellPitch | KBBellDuration, &kb);
+}
 
 /* Pour quitter... */
 void ce_n_est_qu_un_au_revoir ()
@@ -115,6 +147,12 @@ XtInputId *id;
 	    
 	    XtVaSetValues (ecran_minitel, XtNfdConnexion, -1, NULL);
 	    XtRemoveInput (input_id);
+
+	    if (bip_id) {
+		XtRemoveTimeOut (bip_id);
+		bip_id = 0;
+	    }
+
 	    close (socket_xteld);
 	    if (sortie_violente)
 		ce_n_est_qu_un_au_revoir ();
@@ -164,10 +202,15 @@ XtInputId *id;
 		XtVaSetValues (ecran_minitel, XtNconnecte, True, NULL);
 #ifndef LOW_MEMORY
 		if (!low_memory) {
-		    XtVaSetValues (timer_minitel, XtNtimerMode, True, NULL);
+		  if (temps_maxi > 0) {
+		    XtVaSetValues (timer_minitel, XtNtimerMode, True, XtNcountDown, True, XtNmin, temps_maxi/60, XtNsec, temps_maxi%60, NULL);
+		    temps_maxi = 0;
+		  }
+		  else
+		    XtVaSetValues (timer_minitel, XtNtimerMode, True, XtNcountDown, False, XtNmin, 0, XtNsec, 0, NULL);
+		  
 		    timerResetTimer (timer_minitel);
 		    timerStartTimer (timer_minitel);
-		    
 		}
 #endif
 		efface_telephone ();
@@ -175,13 +218,22 @@ XtInputId *id;
 	    
 		/* valide les boutons MINITEL */
 		clavier_minitel_valide (True);
-	    
 		XFlush (XtDisplay(ecran_minitel));
 	    }
 	    else if (c == VALEUR_REPONSE_DEBUT_ERREUR) {
 		erreur = 1;
 		compte_erreur = 0;
 	    }
+	    /* VALEUR_TEMPS_MAXI, puis longueur + temps_maxi */
+	    else if (c == VALEUR_TEMPS_MAXI) {
+	      read (*fid, &c, 1);
+	      read (*fid, buf_temps_maxi, c);
+	      buf_temps_maxi[c] = 0;
+	      temps_maxi = atoi(buf_temps_maxi);
+	      if (temps_maxi > 30)
+		bip_id = XtAppAddTimeOut (XtWidgetToApplicationContext(ecran_minitel), (unsigned long) (temps_maxi - 30) * 1000, (XtTimerCallbackProc) bip_bip, NULL);
+
+	    }
 	}
     }
 }
