@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xaw.c,v 1.17 1997/02/21 17:00:30 pierre Exp $";
+static char rcsid[] = "$Id: xaw.c,v 1.18 1997/07/03 08:23:05 pierre Exp $";
 
 /*
  * Couche Toolkit ATHENA
@@ -235,6 +235,7 @@ static XrmOptionDescRec options[] = {
     {"-ng",		"*nGris",		XrmoptionNoArg, "True"},
     {"-br",		"*boutonRaccrocher",	XrmoptionNoArg, "True"},
     {"-low",		"*lowMemory",		XrmoptionNoArg, "True"},
+    {"-private",	"*privateColormap",	XrmoptionNoArg, "True"},
 };
 
 static void menu_type_arret_page_cb (w, choice, call_data)
@@ -339,11 +340,15 @@ Pixmap unsensitive_bitmap;
 {
     Widget w;
     Pixmap pixmap1 = None, pixmap2 = None, shape1 = None, shape2 = None;
+    XpmAttributes xpma;
+
+    XtVaGetValues (parent, XtNcolormap, &xpma.colormap, NULL);
+    xpma.valuemask = XpmColormap;
 
     if (pixmap1_data)
-      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap1_data, &pixmap1, &shape1, NULL);
+      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap1_data, &pixmap1, &shape1, &xpma);
     if (pixmap2_data)
-      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap2_data, &pixmap2, &shape2, NULL);
+      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap2_data, &pixmap2, &shape2, &xpma);
 
     w = XtVaCreateManagedWidget (name, class, parent, XtNpixmap1, pixmap1, XtNpixmap2, pixmap2, XtNshape1, shape1, XtNshape2, shape2, XtNunsensitiveBitmap, unsensitive_bitmap, NULL);
 
@@ -395,7 +400,7 @@ int width, height;
     long bg;
 
     XtVaGetValues (parent, XtNbackground, &bg, NULL);
-    if ((pixmap = XCreatePixmapFromBitmapData (dpy, DefaultRootWindow(dpy), bits, width, height, BlackPixel (dpy, screen), bg, DisplayPlanes(dpy, screen)))) {
+    if ((pixmap = XCreatePixmapFromBitmapData (dpy, DefaultRootWindow(dpy), bits, width, height, black_pixel /*BlackPixel (dpy, screen)*/, bg, DisplayPlanes(dpy, screen)))) {
 	w = XtVaCreateManagedWidget (name, labelWidgetClass, parent, XtNbitmap, pixmap, XtNmappedWhenManaged, False, NULL);
 	return (w);
     }
@@ -1178,7 +1183,11 @@ XtPointer client_data, call_data;
 
     if (!flag_copyright_affiche) {
 #ifndef NO_XPM
-	XpmCreatePixmapFromData (XtDisplay(top), XtWindow(top), pf_xpm, &pixmap_pf, NULL, NULL);
+	XpmAttributes xpma;
+
+	XtVaGetValues (top, XtNcolormap, &xpma.colormap, NULL);
+	xpma.valuemask = XpmColormap;
+	XpmCreatePixmapFromData (XtDisplay(top), XtWindow(top), pf_xpm, &pixmap_pf, NULL, &xpma);
 #else
 	pixmap_pf = XCreateBitmapFromData (XtDisplay(top), XtWindow(top), pf_bits, pf_width, pf_height);
 #endif /* NO_XPM */
