@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xm.c,v 1.11 1997/01/08 15:03:18 pierre Exp $";
+static char rcsid[] = "$Id: xm.c,v 1.13 1997/07/03 08:23:24 pierre Exp $";
 
 /*
  * Couche Toolkit OSF-MOTIF
@@ -166,6 +166,7 @@ static XrmOptionDescRec options[] = {
     {"-ng",		"*nGris",		XrmoptionNoArg, "True"},
     {"-br",		"*boutonRaccrocher",	XrmoptionNoArg, "True"},
     {"-low",		"*lowMemory",		XrmoptionNoArg, "True"},
+    {"-private",	"*privateColormap",	XrmoptionNoArg, "True"},
 };
 
 /* Callback de selection du type d'arret */
@@ -230,7 +231,7 @@ int width, height;
     long bg;
 
     XtVaGetValues (parent, XtNbackground, &bg, NULL);
-    if ((pixmap = XCreatePixmapFromBitmapData (dpy, DefaultRootWindow(dpy), bits, width, height, BlackPixel (dpy, screen), bg, DisplayPlanes(dpy, screen)))) {
+    if ((pixmap = XCreatePixmapFromBitmapData (dpy, DefaultRootWindow(dpy), bits, width, height, black_pixel /*BlackPixel (dpy, screen)*/, bg, DisplayPlanes(dpy, screen)))) {
 	w = XtVaCreateManagedWidget (name, xmLabelWidgetClass, parent, XmNlabelType, XmPIXMAP, XmNlabelPixmap, pixmap, XtNmappedWhenManaged, False, NULL);
 	return (w);
     }
@@ -255,12 +256,16 @@ char *xpm_data[], *unsensitive_xpm_data[];
 {
     Widget w;
     Pixmap pixmap, unsensitive_pixmap;
+    XpmAttributes xpma;
 
-    XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), xpm_data, &pixmap, NULL, NULL);
+    XtVaGetValues (parent, XtNcolormap, &xpma.colormap, NULL);
+    xpma.valuemask = XpmColormap;
+
+    XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), xpm_data, &pixmap, NULL, &xpma);
     if (pixmap) {
 	w = XtVaCreateManagedWidget (name, class, parent, XmNsensitive, sensitive, XmNlabelType, XmPIXMAP, XmNlabelPixmap, pixmap, NULL);
 	if (unsensitive_xpm_data) {
-	    XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), unsensitive_xpm_data, &unsensitive_pixmap, NULL, NULL);
+	    XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), unsensitive_xpm_data, &unsensitive_pixmap, NULL, &xpma);
 	    XtVaSetValues (w, XmNlabelInsensitivePixmap, unsensitive_pixmap, NULL);
 	}
 
@@ -291,11 +296,15 @@ Pixmap unsensitive_bitmap;
 {
     Widget w;
     Pixmap pixmap1 = None, pixmap2 = None, shape1 = None, shape2 = None;
+    XpmAttributes xpma;
+
+    XtVaGetValues (parent, XtNcolormap, &xpma.colormap, NULL);
+    xpma.valuemask = XpmColormap;
 
     if (pixmap1_data)
-      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap1_data, &pixmap1, &shape1, NULL);
+      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap1_data, &pixmap1, &shape1, &xpma);
     if (pixmap2_data)
-      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap2_data, &pixmap2, &shape2, NULL);
+      XpmCreatePixmapFromData (XtDisplay(parent), DefaultRootWindow(XtDisplay(parent)), pixmap2_data, &pixmap2, &shape2, &xpma);
 
     w = XtVaCreateManagedWidget (name, class, parent, XtNpixmap1, pixmap1, XtNpixmap2, pixmap2, XtNshape1, shape1, XtNshape2, shape2, XtNunsensitiveBitmap, unsensitive_bitmap, NULL);
 
@@ -381,6 +390,7 @@ Widget topLevel;
 {
     register int i;
     Widget entry;
+    XpmAttributes xpma;
 #ifndef LOW_MEMORY
     Pixmap unsensitive_pixmap_h, unsensitive_pixmap_b;
 #endif
@@ -493,11 +503,15 @@ Widget topLevel;
 	(void)create_xpm_button (boite_haut, "btn_nouveau", xpmButtonWidgetClass, nouvel_enregistrement, NULL, nouveau_xpm, None, None, None, unsensitive_pixmap_h);
 	(void)create_xpm_button (boite_haut, "btn_enregistre", xpmButtonWidgetClass, change_enregistrement, NULL, camera_xpm, None, None, None, unsensitive_pixmap_h);
 	btn_lecteur = create_xpm_button (boite_haut, "btn_lecteur", xpmButtonWidgetClass, debut_lecteur, NULL, film_xpm, None, None, None, unsensitive_pixmap_h);
-	btn_direct = create_xpm_button (boite_haut, "btn_direct", xpmButtonWidgetClass, Ouverture_boite_saisie, NULL, phone_xpm, None, None, None, unsensitive_pixmap_h);
+	/* Appel direct */
+	if (nb_services >= 1 && strcmp (entree_compose[nb_services-1], "Direct") == 0)
+	  btn_direct = create_xpm_button (boite_haut, "btn_direct", xpmButtonWidgetClass, Ouverture_boite_saisie, NULL, phone_xpm, None, None, None, unsensitive_pixmap_h);
 	(void)create_xpm_button (boite_haut, "btn_quitte", xpmButtonWidgetClass, Ouverture_confirmation_sortie, NULL, door_run_xpm, None, None, None, unsensitive_pixmap_h);
 
 	/* Cassette */
-	XpmCreatePixmapFromData (XtDisplay(boite_haut), DefaultRootWindow(XtDisplay(boite_haut)), cassete_xpm, &pixmap_k7, NULL, NULL);
+	XtVaGetValues (boite_haut, XtNcolormap, &xpma.colormap, NULL);
+	xpma.valuemask = XpmColormap;
+	XpmCreatePixmapFromData (XtDisplay(boite_haut), DefaultRootWindow(XtDisplay(boite_haut)), cassete_xpm, &pixmap_k7, NULL, &xpma);
 	la_cassete = XtVaCreateManagedWidget ("la_cassete", xmLabelWidgetClass, boite_haut, XmNlabelType, XmPIXMAP, XmNmappedWhenManaged, False, XmNlabelPixmap, pixmap_k7, NULL);
 	teleph = create_bitmap_label (boite_haut, "teleph", teleph_bits, teleph_width, teleph_height);
 	/* Timer */
@@ -857,7 +871,12 @@ XtPointer client_data, call_data;
 
     if (!flag_copyright_affiche) {
 #ifndef NO_XPM
-	XpmCreatePixmapFromData (XtDisplay(top), XtWindow(top), pf_xpm, &pixmap_pf, NULL, NULL);
+	XpmAttributes xpma;
+
+	XtVaGetValues (w, XtNcolormap, &xpma.colormap, NULL);
+	xpma.valuemask = XpmColormap;
+
+	XpmCreatePixmapFromData (XtDisplay(top), XtWindow(top), pf_xpm, &pixmap_pf, NULL, &xpma);
 #else
 	pixmap_pf = XCreateBitmapFromData (XtDisplay(top), XtWindow(top), pf_bits, pf_width, pf_height);
 #endif /* NO_XPM */
