@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xteld.c,v 1.25 1997/02/21 17:02:42 pierre Exp $";
+static char rcsid[] = "$Id: xteld.c,v 1.27 1997/07/11 10:56:40 pierre Exp $";
 
 /*
  * Demon XTELD (communication avec le MODEM)
@@ -262,60 +262,68 @@ static void deconnexion ()
 {
     FILE *fplog;
 
+    if (flag_connexion) {
+
 #ifdef DEBUG_XTELD
-    log_debug ("Deconnecte !");
+	log_debug ("Deconnecte !");
 #endif
-
-    flag_connexion = 0;
-
-    if (!flag_serveur_local) {
-
-	if (definition_lignes[numero_ligne].type_dialer != DIALER_MODEM) {
-
-	    /*
-	     * Envoi du code de connexion/fin puis de la sequence
-	     * de raccrochage
-	     */
-#ifdef DEBUG_XTELD
-	    log_debug ("Raccrochage Minitel");
-#endif
-	    write (fd_modem, "\x13I\x1b\x39\x67", 5);
-	}
-
-	myundial (fd_modem);
-
-    }
-    else
-	kill (pid_fils, SIGTERM);
-
-    /* signal a XTEL la deconnexion */
-    write (XTELD_OUTPUT, CHAINE_REPONSE_DECONNEXION, 1);
-
-    /* supprime le fichier de log */
-    sprintf (buf, "/tmp/.xtel-%s", utilisateur);
-    unlink (buf);
 	
-    if ((fplog= fopen(FICHIER_LOG, "a")) != NULL) {
-	long t= time(0), duree;
-	char *at= ctime(&t);
-	at[24]= '\000';
+	flag_connexion = 0;
+	
+	if (!flag_serveur_local) {
 
-	duree = (t_connexion == 0 ? 0L : t-t_connexion);
-	fprintf(fplog, "%s, %s deconnexion de : %s (%ld s sur %s)\n", at, utilisateur, service, duree, definition_lignes[numero_ligne].nom);
-	fclose(fplog);
+	    if (definition_lignes[numero_ligne].type_dialer != DIALER_MODEM) {
+
+		/*
+		 * Envoi du code de connexion/fin puis de la sequence
+		 * de raccrochage
+		 */
+#ifdef DEBUG_XTELD
+		log_debug ("Raccrochage Minitel");
+#endif
+		write (fd_modem, "\x13I\x1b\x39\x67", 5);
+	    }
+
+	    myundial (fd_modem);
+
+	}
+	else
+	    kill (pid_fils, SIGTERM);
+	
+	/* signal a XTEL la deconnexion */
+	write (XTELD_OUTPUT, CHAINE_REPONSE_DECONNEXION, 1);
+	
+	/* supprime le fichier de log */
+	sprintf (buf, "/tmp/.xtel-%s", utilisateur);
+	unlink (buf);
+	
+	if ((fplog= fopen(FICHIER_LOG, "a")) != NULL) {
+	    long t= time(0), duree;
+	    char *at= ctime(&t);
+	    at[24]= '\000';
+
+	    duree = (t_connexion == 0 ? 0L : t-t_connexion);
+	    fprintf(fplog, "%s, %s deconnexion de : %s (%ld s sur %s)\n", at, utilisateur, service, duree, definition_lignes[numero_ligne].nom);
+	    fclose(fplog);
+	}
+	
+	waitchild ();
+	fin_connexion++;
     }
-
-    waitchild ();
-    fin_connexion++;
 }
 
-/* Test de la mort subite de Xtel (errno == 2) en cours de connexion */
+/* Test de la mort subite de Xtel en cours de connexion (errno != EINTR) */
 static void test_mort_subite ()
 {
-    if (errno == SIGINT && flag_connexion) {
-	kill (pid_fils, SIGTERM);
-	deconnexion ();
-    }
+#ifdef DEBUG_XTELD
+      log_debug ("test_mort_subite: errno=%d", errno);
+#endif
+      /* Si l'erreur est bizarre et que l'on est toujours connecte, 
+	 force la deconnexion */
+      if (errno != EINTR && flag_connexion) {
+	  kill (pid_fils, SIGTERM);
+	  deconnexion ();
+      }
 }    
 
 /* Test chaine = nombre */
@@ -565,10 +573,12 @@ char *service_teletel;
 	fin_fils = 0;
 	while (!fin_fils) {
 	    int nread, size, i;
+	    fd_set t_a_lire;
 	    
 	    timeout.tv_sec = (unsigned long)DELAI_DECONNEXION;
 
-	    nread = select (32, &a_lire, NULL, NULL, (flag_serveur_local ? NULL : &timeout));
+	    t_a_lire = a_lire;
+	    nread = select (32, &t_a_lire, NULL, NULL, (flag_serveur_local ? NULL : &timeout));
 
 	    if (nread < 0 && errno == EINTR) {
 		/* select() interrompu par le SIGTERM du parent */
@@ -578,7 +588,7 @@ char *service_teletel;
 		continue;
 	    }
 	    
-	    if (nread == 0 || !FD_ISSET (fd_modem, &a_lire)) {
+	    if (nread == 0 || !FD_ISSET (fd_modem, &t_a_lire)) {
 		/* read = 0 (timeout) ==> deconnexion */
 #ifdef DEBUG_XTELD
 		log_debug ("read = 0 (timeout) ==> deconnexion");
